<?php

namespace App\ContentModule\Model;

use App\Model\BaseManager;

/**
 * Třída poskytuje metody pro správu objednávek.
 * @package App\ContentModule\Model
 */
class OrderManager extends BaseManager {

    /** Konstanty pro manipulaci s modelem. */
    const
            TABLE_NAME = 'orders',
            COLUMN_ID = 'order_id',
            COLUMN_USER = 'user_id',
            COLUMN_MENU = 'menu_id';

    /**
     * Vrátí seznam objednávek uživatele.
     */
    public function getOrdersByUser($userId) {
        return $this->database->table(self::TABLE_NAME)->where(self::COLUMN_USER, $userId)->order(self::COLUMN_ID);
    }

    /**
     * Vrátí objednávku uživatele na konkrétní datum
     */
    public function getOrderByUserADate($userId, $date) {
        $orders = $this->database->table(self::TABLE_NAME)->where(self::COLUMN_USER, $userId)->order(self::COLUMN_ID);
        foreach ($orders as $order) {
            if ($order->menu->date->format('Y-m-d') == $date) {
                return $order;
            }
        }
        return null;
    }

    /**
     * Uloží objednávku do systému. V případě že ještě objednávka vytvořena není, založí novou.
     */
    public function saveOrder($userId, $menuId, $orderId = NULL) {
        if ($orderId == null) {
            $order = $this->database->table(self::TABLE_NAME)->where(self::COLUMN_USER . ' ? AND ' . self::COLUMN_MENU . ' ?', $userId, $menuId)->fetch();
        } else {
            $order = $this->database->table(self::TABLE_NAME)->where(self::COLUMN_ID, $orderId)->fetch();
        }
        if ($order == null) {
            // Pokusí se vložit nového uživatele do databáze.
            $this->database->table(self::TABLE_NAME)->insert(array(
                self::COLUMN_USER => $userId,
                self::COLUMN_MENU => $menuId,
            ));
        } else {
            $this->database->table(self::TABLE_NAME)->where(self::COLUMN_ID, $orderId)->update([
                self::COLUMN_USER => $userId,
                self::COLUMN_MENU => $menuId,
            ]);
        }
    }

    /**
     * Vymaže objednávku.
     */
    public function removeOrder($orderId) {
        $this->database->table(self::TABLE_NAME)->where(self::COLUMN_ID, $orderId)->delete();
    }

}
