<?php

namespace App\ContentModule\Presenters;

use App\ContentModule\Model\MenuManager;
use App\ContentModule\Model\OrderManager;
use Nette\Utils\DateTime;
use Nette\Application\UI\Form;

/**
 * Zpracovává vykreslování jídelníčku.
 * @package App\ContentModule\Presenters
 */
class MenuPresenter extends BaseContentPresenter {

    protected $menuManager;

    protected $orderManager;

    /**
     * Konstruktor s injektovaným modelem pro práci s jídelníčkem a objednávkami.
     */
    public function __construct(MenuManager $menuManager, OrderManager $orderManager) {
        parent::__construct();
        $this->menuManager = $menuManager;
        $this->orderManager = $orderManager;
    }

    //Načte a vykreslí aktuální jídelníček.
    public function renderDefault() {
        $this->template->menus = $this->menuManager->getActualMenus();
        $date = DateTime::from(date('Y-m-d'));
        $date->modify('-1 day');
        $this->template->date = $date->format('Y-m-d');
        $identity = $this->getUser()->getIdentity();
        if ($identity) {
            $this->template->orders = $this->orderManager->
                    getOrdersByUser($identity->getData()['user_id']);
        }
        $this->template->checked = '';
    }

    //Zpracovává formulář pro odeslání objednávek
    protected function createComponentMenuForm(): Form {
        $form = new Form;
        $form->onSuccess[] = function (Form $form) {

            if (!empty($_POST["send"])) {
                $identity = $this->getUser()->getIdentity();
                $user_id = 0;
                if ($identity)
                    { $user_id = $identity->getData()['user_id']; }
                $orderArray = $this->orderManager->
                        getOrdersByUser($user_id);
                foreach ($orderArray as $order) {
                    if (empty($_POST[$order->menu->date->format('Y-m-d')])) {
                        $this->orderManager->removeOrder($order->order_id);
                    }
                }

                foreach ($_POST as $key => $value) {
                    if ($key != 'send' && $key != '_do') {
                        $order = $this->orderManager->getOrderByUserADate($user_id, $key);
                        if ($order != null) {
                            if ($order->menu_id != $value) {
                                $this->orderManager->saveOrder($user_id, $value, $order->order_id);
                            }
                        } else {
                            $this->orderManager->saveOrder($user_id, $value);
                        }
                    }
                }
                $this->flashMessage('Objednávky byly úspěšně uloženy.');
            }
        };
        return $form;
    }

}
